@@ -4,6 +4,7 @@ import logging
 import os
 import time
 import traceback
+from typing import Optional
 import uuid
 from contextlib import contextmanager
 import decimal
@@ -116,7 +117,17 @@ class Tracer(Base):
         span_errors = [x.error for x in spans]
         return True not in span_errors
 
-    def close(self, **kwargs):
+    def serilizer_data(self, data: dict, **kwargs) -> Optional[str]:
+        env = kwargs.get('env', os.environ.get('ENV'))
+        data_serilized = None
+        try:
+            data_serilized = json.dumps(data, cls=DecimalEncoder)
+        except Exception as e:
+            if env != 'production':
+                raise e
+        return data_serilized
+
+    def close(self, **kwargs) -> dict:
         data = {
             'id': self.id,
             'service': self.service,
@@ -124,18 +135,11 @@ class Tracer(Base):
             'is_success': self.is_success,
             'spans': [x.to_dict() for x in self.spans]
         }
-        env = kwargs.get('env', os.environ.get('ENV'))
-        is_convert_success = True
-        try:
-            data = json.dumps(data, cls=DecimalEncoder)
-        except Exception as e:
-            is_convert_success = False
-            if env != 'production':
-                raise e
 
         if kwargs.get('log', True):
-            if is_convert_success:
-                logging.info('instrumenting-trace {}'.format(data))
+            data_serilized = self.serilizer_data(data, env=kwargs.get('env'))
+            if data_serilized is not None:
+                logging.info('instrumenting-trace {}'.format(data_serilized))
             else:
                 logging.error('instrumenting-error-trace error by convert')
 
@@ -143,7 +147,7 @@ class Tracer(Base):
 
 
 class DjangoAPITracer(Tracer):
-    def __init__(self, request):
+    def __init__(self, request, **kwargs):
         operation = "HTTP {} {}".format(
             request.method,
             request.path,
@@ -153,7 +157,11 @@ class DjangoAPITracer(Tracer):
 
         try:
             request_data = json.dumps(request.data, cls=DecimalEncoder)
-        except:
+            request_data = request.data
+        except Exception as e:
+            env = kwargs.get('env', os.environ.get('ENV'))
+            if env != 'production':
+                raise e
             request_data = {}
 
         self.context = {
@@ -169,16 +177,17 @@ class DjangoAPITracer(Tracer):
             },
         }
 
-    def close(self, **kwargs):
+    def close(self, **kwargs) -> dict:
         data = {
             **super().close(log=False),
             'context': self.context,
         }
 
         if kwargs.get('log', True):
-            try:
-                logging.info('instrumenting-trace {}'.format(json.dumps(data, cls=DecimalEncoder)))
-            except Exception as e:
+            data_serilized = self.serilizer_data(data, env=kwargs.get('env'))
+            if data_serilized is not None:
+                logging.info('instrumenting-trace {}'.format(data_serilized))
+            else:
                 logging.error('instrumenting-error-trace error by convert')
 
         return data
